@@ -26,7 +26,7 @@ struct ColorSurface::pImpl {
   bool is_changed;
 
   pImpl(Uint32 color, size_t w, size_t h)
-    : scr(SDL_GetVideoSurface()), width(w), height(h), is_changed(true) {
+    : scr(SDL_GetVideoSurface()), width(w), height(h), is_changed(false) {
     if (scr == NULL) {
       LogManager* log = LogManager::getObject();
       std::string message = "SdlSurface::pImpl(): "
@@ -66,6 +66,11 @@ size_t ColorSurface::getHeight(void) {
 }
 
 
+void ColorSurface::forceSetChanged(void) {
+  pimpl->is_changed = true;
+}
+
+
 bool ColorSurface::isChanged(void) {
   bool ret = pimpl->is_changed;
   pimpl->is_changed = false;
