@@ -117,6 +117,9 @@ void CommonResources::initializeMusic(void) {
     }
     sound_effect = new SoundEffectManager;
 
+    // Đ
+    music->setFadeInEffect(PlayFadeIn);
+
     // y̏
     music->registerMusic(BackMusic_1, Music1_FilePath);
     music->registerMusic(BackMusic_2, Music2_FilePath);
