@@ -19,6 +19,7 @@
 #include "hyakutyping.h"
 #include "DrawsDefinition.h"
 #include "CommonResources.h"
+#include "ResourceDefinition.h"
 #include "PracticeMenu.h"
 #include "NetworkMenu.h"
 #include "OptionMenu.h"
@@ -29,6 +30,7 @@
 #include "ButtonComponent.h"
 #include "MenuComponent.h"
 #include "InputHandler.h"
+#include "MusicManager.h"
 #include "LockGuard.h"
 #include "SdlUtils.h"
 #include "Delay.h"
@@ -117,6 +119,11 @@ FirstMenu::~FirstMenu(void) {
 
 void FirstMenu::run(void) {
 
+  // y̍Đ
+  if (pimpl->common->music) {
+    pimpl->common->music->setNextMusic(BackMusic_1);
+  }
+
   InputHandler& input = *pimpl->common->input;
   bool quit = false;
   while (quit == false) {
