@@ -14,6 +14,7 @@
 #include "LockGuard.h"
 #include "SurfaceInterface.h"
 #include "Delay.h"
+#include "GetTicks.h"
 #include "InputHandler.h"
 #include "InputEvent.h"
 
@@ -72,12 +73,15 @@ struct GuiManager::pImpl {
 
     delay(1);
 
+    // !!! AVXeɓo^ ticks g悤ɕύXBKvɉ
+    size_t ticks = GetTicks();
+
     // T[tFXXg̍č\z
     LockMutex(data->mutex);
     //fprintf(stderr, "at GuiManager::pImpl::update_thread\n");
     data->layer_manager.createComponentList(data->component_list);
     data->layer_manager.createSurfaceList(data->surface_list,
-					  data->component_list);
+					  data->component_list, ticks);
 
     // ̓Cxg̔f
     data->input.updateInputEvent(data->input_event);
