@@ -28,12 +28,14 @@ namespace beego {
     InputReceiveComponent(void);
     ~InputReceiveComponent(void);
 
-    void addSurfaceList(SurfaceList& surfaces, const SDL_Rect* area);
+    void addSurfaceList(SurfaceList& surfaces, const SDL_Rect* area,
+			size_t ticks);
     void setPosition(const SDL_Rect* position);
     void getPosition(SDL_Rect* position);
     size_t getWidth(void);
     size_t getHeight(void);
     void applyInput(const InputEvent& event);
+    void registerLayer(Layer* layer);
 
     void clear(void);
     void updateInputEvent(InputEvent& event);
