@@ -39,7 +39,7 @@ LabelComponent::~LabelComponent(void) {
 
 
 void LabelComponent::addSurfaceList(SurfaceList& surfaces,
-				    const SDL_Rect* area) {
+				    const SDL_Rect* area, size_t ticks) {
 
   updateDrawSurface(pimpl->draw_surface, pimpl->surface, area,
 		    pimpl->position, pimpl->position_changed);
@@ -73,3 +73,8 @@ size_t LabelComponent::getHeight(void) {
 void LabelComponent::applyInput(const InputEvent& event) {
   // !!!
 }
+
+
+void LabelComponent::registerLayer(Layer* layer) {
+  // Ȃ
+}
