@@ -31,12 +31,14 @@ namespace beego {
     explicit LabelComponent(Surface surface);
     ~LabelComponent(void);
 
-    void addSurfaceList(SurfaceList& surfaces, const SDL_Rect* area);
+    void addSurfaceList(SurfaceList& surfaces, const SDL_Rect* area,
+			size_t ticks);
     void setPosition(const SDL_Rect* position);
     void getPosition(SDL_Rect* position);
     size_t getWidth(void);
     size_t getHeight(void);
     void applyInput(const InputEvent& event);
+    void registerLayer(Layer* layer);
   };
 };
 
