@@ -31,11 +31,14 @@ namespace beego {
     ~Layer(void);
 
     void addComponentList(ComponentList& components) const;
-    void addSurfaceList(SurfaceList& surfaces, const SDL_Rect* area);
+    void addSurfaceList(SurfaceList& surfaces, const SDL_Rect* area,
+			size_t ticks);
     void push_front(Component component);
     void push_back(Component component);
     void insert(const Component dst, Component component);
     void remove(Component component);
+
+    void removeSurfaces(SurfaceList& surfaces);
     void registerManager(LayerManager* obj);
 
     void enable(void);
