@@ -42,9 +42,7 @@ namespace beego {
     void remove(Layer* layer);
     void createComponentList(ComponentList& components);
     void createSurfaceList(SurfaceList& surfaces,
-			   const ComponentList& components);
-    //void removeSurface(DrawSurface& draw_surface, const SDL_Rect* remove_rect);
-    //void removeSurface(SurfaceList& remove_list, const SDL_Rect* remove_rect);
+			   const ComponentList& components, size_t ticks);
     void removeSurface(SurfaceList& remove_list);
   };
 };
