@@ -14,6 +14,7 @@
 #include "ResultDrawer.h"
 #include "ResultDrawer_uni.h"
 #include "DrawsDefinition.h"
+#include "SystemDefinition.h"
 #include "CommonResources.h"
 #include "TypingRecorder.h"
 #include "GuiManager.h"
@@ -24,6 +25,7 @@
 #include "TextSurface.h"
 #include "TextFadeSurface.h"
 #include "LabelComponent.h"
+#include "MusicManager.h"
 #include "LockGuard.h"
 #include "SdlUtils.h"
 #include "UtfString.h"
@@ -285,6 +287,14 @@ void ResultDrawer::createResult(void) {
 
   // R|[lg̔zu
   pimpl->placeComponents();
+
+  // y̒~
+  if (pimpl->common->music) {
+    pimpl->common->music->stop(StopFadeOut);
+
+    // ʉ̍Đ
+    // !!!
+  }
 }
 
 
