@@ -29,6 +29,8 @@ namespace beego {
     SDL_Rect area;		//!< ItZbgATCY
     Surface surface;		//!< T[tFX
     bool position_changed;	//!< zuύXꂽ
+    bool is_changed;
+    bool is_transparent;
     std::vector<SDL_Rect> redraw_rects; //!< ĕ`̈
   };
 
