@@ -45,4 +45,10 @@ enum {
 #endif
 };
 
+// y̍Đ܂
+enum {
+  PlayFadeIn = 1000,
+  StopFadeOut = 200,
+};
+
 #endif /* !SYSTEM_DEFINITION_H */
